import validators

def is_even(num: int):
	if not isinstance(num, int):
		raise Exception("Invalid num: ", num)
	return num % 2 == 0
		
def is_odd(num: int):
	if not isinstance(num, int):
		raise Exception("Invalid num: ", num)
	return num % 2 != 0
		
		
def is_even_or_odd(num: int):
	if not isinstance(num, int):
		raise Exception("Invalid num: ", num)
	return "Even" if num % 2 == 0 else "Odd"


def is_url_valid(url: int):
	if not isinstance(url, str):
		raise Exception("Invalid input url. Expected a string")
	if not validators.url(url):
		return "Invalid"
	return "Valid"



from setuptools import setup, find_packages

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name='isevenoroddpkg',
    version='1.0.0',
    description="Number validator",
    long_description=long_description,
    author="Parmeshwar",
    author_email="parmeshwar@mindkosh.com",
    packages=find_packages(),
    include_package_data=True,
    python_requires='>=3.7',
    install_requires=[
        "validators==0.20.0"
    ],
    keywords=["even-odd-validator"],
)
